==> zio-aws-groundstation_2.12-5.17.267.4-sources.jar: zio/aws/groundstation/model/DeleteConfigRequest.scala <==
package zio.aws.groundstation.model
import zio.ZIO
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters._
final case class DeleteConfigRequest(
    configId: String,
    configType: zio.aws.groundstation.model.ConfigCapabilityType
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.groundstation.model.DeleteConfigRequest = {
    import DeleteConfigRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.groundstation.model.DeleteConfigRequest
      .builder()
      .configId(configId: java.lang.String)
      .configType(configType.unwrap)
      .build()
  }
  def asReadOnly: zio.aws.groundstation.model.DeleteConfigRequest.ReadOnly =
    zio.aws.groundstation.model.DeleteConfigRequest.wrap(buildAwsValue())
}
object DeleteConfigRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.groundstation.model.DeleteConfigRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.groundstation.model.DeleteConfigRequest =
      zio.aws.groundstation.model.DeleteConfigRequest(configId, configType)
    def configId: String
    def configType: zio.aws.groundstation.model.ConfigCapabilityType
    def getConfigId: ZIO[Any, Nothing, String] = ZIO.succeed(configId)
    def getConfigType
        : ZIO[Any, Nothing, zio.aws.groundstation.model.ConfigCapabilityType] =
      ZIO.succeed(configType)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.groundstation.model.DeleteConfigRequest
  ) extends zio.aws.groundstation.model.DeleteConfigRequest.ReadOnly {
    override val configId: String = impl.configId(): String
    override val configType: zio.aws.groundstation.model.ConfigCapabilityType =
      zio.aws.groundstation.model.ConfigCapabilityType.wrap(impl.configType())
  }
  def wrap(
      impl: software.amazon.awssdk.services.groundstation.model.DeleteConfigRequest
  ): zio.aws.groundstation.model.DeleteConfigRequest.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-groundstation_2.12-5.20.37.1-sources.jar: zio/aws/groundstation/model/DeleteConfigRequest.scala <==
package zio.aws.groundstation.model
import zio.aws.groundstation.model.primitives.Uuid
import zio.ZIO
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters._
final case class DeleteConfigRequest(
    configId: Uuid,
    configType: zio.aws.groundstation.model.ConfigCapabilityType
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.groundstation.model.DeleteConfigRequest = {
    import DeleteConfigRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.groundstation.model.DeleteConfigRequest
      .builder()
      .configId(Uuid.unwrap(configId): java.lang.String)
      .configType(configType.unwrap)
      .build()
  }
  def asReadOnly: zio.aws.groundstation.model.DeleteConfigRequest.ReadOnly =
    zio.aws.groundstation.model.DeleteConfigRequest.wrap(buildAwsValue())
}
object DeleteConfigRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.groundstation.model.DeleteConfigRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.groundstation.model.DeleteConfigRequest =
      zio.aws.groundstation.model.DeleteConfigRequest(configId, configType)
    def configId: Uuid
    def configType: zio.aws.groundstation.model.ConfigCapabilityType
    def getConfigId: ZIO[Any, Nothing, Uuid] = ZIO.succeed(configId)
    def getConfigType
        : ZIO[Any, Nothing, zio.aws.groundstation.model.ConfigCapabilityType] =
      ZIO.succeed(configType)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.groundstation.model.DeleteConfigRequest
  ) extends zio.aws.groundstation.model.DeleteConfigRequest.ReadOnly {
    override val configId: Uuid =
      zio.aws.groundstation.model.primitives.Uuid(impl.configId())
    override val configType: zio.aws.groundstation.model.ConfigCapabilityType =
      zio.aws.groundstation.model.ConfigCapabilityType.wrap(impl.configType())
  }
  def wrap(
      impl: software.amazon.awssdk.services.groundstation.model.DeleteConfigRequest
  ): zio.aws.groundstation.model.DeleteConfigRequest.ReadOnly = new Wrapper(
    impl
  )
}
